@@ -1,6 +1,7 @@
-from .responses import ElasticsearchServiceResponse
 from moto.opensearch.responses import OpenSearchServiceResponse
 
+from .responses import ElasticsearchServiceResponse
+
 url_bases = [
     r"https?://es\.(.+)\.amazonaws\.com",
 ]
@@ -15,6 +16,6 @@ url_paths = {
     "{0}/2021-01-01/opensearch/domain": OpenSearchServiceResponse.dispatch,
     "{0}/2021-01-01/opensearch/domain/(?P<domainname>[^/]+)": OpenSearchServiceResponse.dispatch,
     "{0}/2021-01-01/opensearch/domain/(?P<domainname>[^/]+)/config": OpenSearchServiceResponse.dispatch,
-    "{0}/2021-01-01/tags/": OpenSearchServiceResponse.dispatch,
+    "{0}/2021-01-01/tags/?": OpenSearchServiceResponse.dispatch,
     "{0}/2021-01-01/tags-removal/": OpenSearchServiceResponse.dispatch,
 }
